from .user_cf import UserCF
from .item_cf import ItemCF
from .svd import SVD
from .svdpp import SVDpp
from .als import ALS
from .bpr import BPR
from .ncf import NCF
from .youtube_match import YouTubeMatch
from .youtube_ranking import YouTubeRanking
from .fm import FM
from .wide_deep import WideDeep
from .deepfm import DeepFM
from .autoint import AutoInt
from .din import DIN
from .knn_embed import KnnEmbedding, KnnEmbeddingApproximate
from .rnn4rec import RNN4Rec
from .caser import Caser
from .wave_net import WaverNet
